django_analyses.serializers.output.types package — django_analyses 0.0.3 documentation

# django_analyses.serializers.output.types package

## Submodules

## django_analyses.serializers.output.types.file_output module

class `django_analyses.serializers.output.types.file_output.` `FileOutputSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.ModelSerializer`

  class `Meta`

    Bases: `object`

    `fields` = ('id', 'key', 'value', 'run', 'definition')
    `model`

      alias of `django_analyses.models.output.types.file_output.FileOutput`

## Module contents